"""Fuck Of As A Package.

Faster Python version of FOAAS.
Fully FOAAS API compliant.
Check the README for more documentation.
"""


def absolutely(company: str, from_name: str) -> str:
    return f"Absolutely fucking Not, {company}, No Fucking Way! - {from_name}"


def anyway(company: str, from_name: str) -> str:
    return f"Who the fuck are you anyway, {company}, why are you stirring up so much trouble, and, who pays you? - {from_name}"


def ashole(from_name: str) -> str:
    return f"Fuck you, asshole. - {from_name}"


def awesome(from_name: str) -> str:
    return f"This is Fucking Awesome. - {from_name}"


def bag(from_name: str) -> str:
    return f"Eat a bag of fucking dicks. - {from_name}"


def balmer(name: str, company: str, from_name: str) -> str:
    return f"Fucking {name} is a fucking pussy. I'm going to fucking bury that guy, I have done it before, and I will do it again. I'm going to fucking kill {company}. - {from_name}"


def back(name: str, from_name: str) -> str:
    return f"{name}, back the fuck off. - {from_name}"


def bday(name: str, from_name: str) -> str:
    return f"Happy Fucking Birthday, {name}. - {from_name}"


def because(from_name: str) -> str:
    return f"Why? Because fuck you, that's why. - {from_name}"


def blackadder(name: str, from_name: str) -> str:
    return f"{name}, your head is as empty as a eunuch’s underpants. Fuck off! - {from_name}"


def bm(name: str, from_name: str) -> str:
    return f"Bravo mike, {name}. - {from_name}"


def bucket(from_name: str) -> str:
    return f"Please choke on a bucket of cocks. - {from_name}"


def bus(name: str, from_name: str) -> str:
    return f"Christ on a bendy-bus, {name}, don't be such a fucking faff-arse. - {from_name}"


def bye(from_name: str) -> str:
    return f"Fuckity bye! - {from_name}"


def caniuse(tool: str, from_name: str) -> str:
    return f"Can you use {tool}? Fuck no! - {from_name}"


def chainsaw(name: str, from_name: str) -> str:
    return f"Fuck me gently with a chainsaw, {name}. Do I look like Mother Teresa? - {from_name}"


def cocksplat(name: str, from_name: str) -> str:
    return f"Fuck off {name}, you worthless cocksplat - {from_name}"


def cool(from_name: str) -> str:
    return f"Cool story, bro. - {from_name}"


def cup(from_name: str) -> str:
    return f"How about a nice cup of shut the fuck up? - {from_name}"


def dalton(name: str, from_name: str) -> str:
    return f"{name}: A fucking problem solving super-hero. - {from_name}"


def dense(from_name: str) -> str:
    return f"You disingenuous dense motherfucker! - {from_name}"


def deraadt(name: str, from_name: str) -> str:
    return f"{name} you are being the usual slimy hypocritical asshole... You may have had value ten years ago, but people will see that you don't anymore. - {from_name}"


def diabetes(from_name: str) -> str:
    return f"I'd love to stop and chat to you but I'd rather have type 2 diabetes. - {from_name}"


def donut(name: str, from_name: str) -> str:
    return (
        f"{name}, go and take a flying fuck at a rolling donut. - {from_name}"
    )


def dosomething(do: str, something: str, from_name: str) -> str:
    return f"{do} the fucking {something}! - {from_name}"


def dumbledore(from_name: str) -> str:
    return f"Happiness can be found, even in the darkest of times, if one only remembers to fuck off. - {from_name}"


def equity(name: str, from_name: str) -> str:
    return f"Equity only? Long hours? Zero Pay? Well {name}, just sign me right the fuck up. - {from_name}"


def even(from_name: str) -> str:
    return f"I can't fuckin' even. - {from_name}"


def everyone(from_name: str) -> str:
    return f"Everyone can go and fuck off. - {from_name}"


def everything(from_name: str) -> str:
    return f"Fuck everything. - {from_name}"


def family(from_name: str) -> str:
    return f"Fuck you, your whole family, your pets, and your feces. - {from_name}"


def fascinating(from_name: str) -> str:
    return f"Fascinating story, in what chapter do you shut the fuck up? - {from_name}"


def fewer(name: str, from_name: str) -> str:
    return f"Go fuck yourself {name}, you'll disappoint fewer people. - {from_name}"


def field(name: str, from_name: str, reference: str) -> str:
    return f"And {name} said unto {from_name}, 'Verily, cast thine eyes upon the field in which I grow my fucks', and {from_name} gave witness unto the field, and saw that it was barren. - {reference}"


def flying(from_name: str) -> str:
    return f"I don't give a flying fuck. - {from_name}"


def ftfy(from_name: str) -> str:
    return f"Fuck That, Fuck You - {from_name}"


def fts(name: str, from_name: str) -> str:
    return f"Fuck that shit, {name}. - {from_name}"


def fyyff(from_name: str) -> str:
    return f"Fuck you, you fucking fuck. - {from_name}"


def gfy(name: str, from_name: str) -> str:
    return f"Golf foxtrot yankee, {name}. - {from_name}"


def give(from_name: str) -> str:
    return f"I give zero fucks. - {from_name}"


def greed(noun: str, from_name: str) -> str:
    return f"The point is, ladies and gentleman, that {noun} -- for lack of a better word -- is good. {noun} is right. {noun} works. {noun} clarifies, cuts through, and captures the essence of the evolutionary spirit. {noun}, in all of its forms -- {noun} for life, for money, for love, knowledge -- has marked the upward surge of mankind. - {from_name}"


def holygrail(from_name: str) -> str:
    return f"I don't want to talk to you, no more, you empty-headed animal, food trough wiper. I fart in your general direction. Your mother was a hamster and your father smelt of elderberries. Now go away or I shall taunt you a second time. - {from_name}"


def horse(from_name: str) -> str:
    return f"Fuck you and the horse you rode in on. - {from_name}"


def idea(from_name: str) -> str:
    return f"That sounds like a fucking great idea! - {from_name}"


def immensity(from_name: str) -> str:
    return f"You can not imagine the immensity of the FUCK I do not give. - {from_name}"


def ing(name: str, from_name: str) -> str:
    return f"Fucking fuck off, {name}. - {from_name}"


def jinglebells(from_name: str) -> str:
    return f"Fuck you, fuck me, fuck your family. Fuck your father, fuck your mother, fuck you and me. - {from_name}"


def keep(name: str, from_name: str) -> str:
    return f"{name}: Fuck off. And when you get there, fuck off from there too. Then fuck off some more. Keep fucking off until you get back here. Then fuck off again. - {from_name}"


def keepcalm(reaction: str, from_name: str) -> str:
    return f"Keep the fuck calm and {reaction}! - {from_name}"


def king(name: str, from_name: str) -> str:
    return f"Oh fuck off, just really fuck off you total dickface. Christ, {name}, you are fucking thick. - {from_name}"


def legend(name: str, from_name: str) -> str:
    return f"{name}, you're a fucking legend. - {from_name}"


def life(from_name: str) -> str:
    return f"Fuck my life. - {from_name}"


def linus(name: str, from_name: str) -> str:
    return f"{name}, there aren't enough swear-words in the English language, so now I'll have to call you perkeleen vittupää just to express my disgust and frustration with this crap. - {from_name}"


def logs(from_name: str) -> str:
    return f"Check your fucking logs! - {from_name}"


def look(name: str, from_name: str) -> str:
    return f"{name}, do I look like I give a fuck? - {from_name}"


def looking(from_name: str) -> str:
    return f"Looking for a fuck to give. - {from_name}"


def lowpoly(from_name: str) -> str:
    return f"You low polygon motherfucker! - {from_name}"


def madison(name: str, from_name: str) -> str:
    return f"What you've just said is one of the most insanely idiotic things I have ever heard, {name}. At no point in your rambling, incoherent response were you even close to anything that could be considered a rational thought. Everyone in this room is now dumber for having listened to it. I award you no points :name, and may God have mercy on your soul. - {from_name}"


def maybe(from_name: str) -> str:
    return f"Maybe. Maybe not. Maybe fuck yourself. - {from_name}"


def me(from_name: str) -> str:
    return f"Fuck me. - {from_name}"


def mornin(from_name: str) -> str:
    return f"Happy fuckin' mornin'! - {from_name}"


def no(from_name: str) -> str:
    return f"No fucks given. - {from_name}"


def nugget(name: str, from_name: str) -> str:
    return f"Well {name}, aren't you a shining example of a rancid fuck-nugget. - {from_name}"


def off(name: str, from_name: str) -> str:
    return f"Fuck off, {name}. - {from_name}"


def off_with(behavior: str, from_name: str) -> str:
    return f"Fuck off with {behavior} - {from_name}"


def outside(name: str, from_name: str) -> str:
    return f"{name}, why don't you go outside and play hide-and-go-fuck-yourself? - {from_name}"


def particular(thing: str, from_name: str) -> str:
    return f"Fuck this {thing} in particular. - {from_name}"


def pink(from_name: str) -> str:
    return f"Well, fuck me pink. - {from_name}"


def problem(name: str, from_name: str) -> str:
    return f"What the fuck is your problem {name}? - {from_name}"


def programmer(from_name: str) -> str:
    return f"Fuck you, I'm a programmer, bitch! - {from_name}"


def pulp(language: str, from_name: str) -> str:
    return f"{language}, motherfucker, do you speak it? - {from_name}"


def question(from_name: str) -> str:
    return (
        f"To fuck off, or to fuck off (that is not a question) - {from_name}"
    )


def ratsarse(from_name: str) -> str:
    return f"I don't give a rat's arse. - {from_name}"


def retard(from_name: str) -> str:
    return f"You Fucktard! - {from_name}"


def ridiculous(from_name: str) -> str:
    return f"That's fucking ridiculous - {from_name}"


def rockstar(name: str, from_name: str) -> str:
    return f"{name}, you're a fucking Rock Star! - {from_name}"


def rtfm(from_name: str) -> str:
    return f"Read the fucking manual! - {from_name}"


def sake(from_name: str) -> str:
    return f"For Fuck's sake! - {from_name}"


def shakespeare(name: str, from_name: str) -> str:
    return f"{name}, Thou clay-brained guts, thou knotty-pated fool, thou whoreson obscene greasy tallow-catch! - {from_name}"


def shit(from_name: str) -> str:
    return f"Fuck this shit! - {from_name}"


def shutup(name: str, from_name: str) -> str:
    return f"{name}, shut the fuck up. - {from_name}"


def single(from_name: str) -> str:
    return f"Not a single fuck was given. - {from_name}"


def thanks(from_name: str) -> str:
    return f"Fuck you very much. - {from_name}"


def that(from_name: str) -> str:
    return f"Fuck that. - {from_name}"


def think(name: str, from_name: str) -> str:
    return f"{name}, you think I give a fuck? - {from_name}"


def thinking(name: str, from_name: str) -> str:
    return f"{name}, what the fuck were you actually thinking? - {from_name}"


def this(from_name: str) -> str:
    return f"Fuck this. - {from_name}"


def thumbs(name: str, from_name: str) -> str:
    return f"Who has two thumbs and doesn't give a fuck? {name}. - {from_name}"


def too(from_name: str) -> str:
    return f"Thanks, fuck you too. - {from_name}"


def tucker(from_name: str) -> str:
    return f"Come the fuck in or fuck the fuck off. - {from_name}"


def understand(name: str, from_name: str) -> str:
    return f"Listen here {name}! What part of 'Fuck Off' don't you understand? - {from_name}"


def waste(name: str, from_name: str) -> str:
    return f"I don't waste my fucking time with your bullshit {name}! - {from_name}"


def what(from_name: str) -> str:
    return f"What the fuck‽ - {from_name}"


def xmas(name: str, from_name: str) -> str:
    return f"Merry Fucking Christmas, {name}. - {from_name}"


def yeah(from_name: str) -> str:
    return f"Fuck YEAH! - {from_name}"


def yoda(name: str, from_name: str) -> str:
    return f"Fuck off, you must, {name}. - {from_name}"


def you(name: str, from_name: str) -> str:
    return f"Fuck you, {name}. - {from_name}"


def zayn(from_name: str) -> str:
    return f"Ask me if I give a motherfuck ?!! - {from_name}"


def zero(from_name: str) -> str:
    return f"Zero, that's the number of fucks I give. - {from_name}"


__all__ = [
    "absolutely",
    "anyway",
    "ashole",
    "awesome",
    "bag",
    "balmer",
    "back",
    "bday",
    "because",
    "blackadder",
    "bm",
    "bucket",
    "bus",
    "bye",
    "caniuse",
    "chainsaw",
    "cocksplat",
    "cool",
    "cup",
    "dalton",
    "dense",
    "deraadt",
    "diabetes",
    "donut",
    "dosomething",
    "dumbledore",
    "equity",
    "even",
    "everyone",
    "everything",
    "family",
    "fascinating",
    "fewer",
    "field",
    "flying",
    "ftfy",
    "fts",
    "fyyff",
    "gfy",
    "give",
    "greed",
    "holygrail",
    "horse",
    "idea",
    "immensity",
    "ing",
    "jinglebells",
    "keep",
    "keepcalm",
    "king",
    "legend",
    "life",
    "linus",
    "logs",
    "look",
    "looking",
    "lowpoly",
    "madison",
    "maybe",
    "me",
    "mornin",
    "no",
    "nugget",
    "off",
    "off_with",
    "outside",
    "particular",
    "pink",
    "problem",
    "programmer",
    "pulp",
    "question",
    "ratsarse",
    "retard",
    "ridiculous",
    "rockstar",
    "rtfm",
    "sake",
    "shakespeare",
    "shit",
    "shutup",
    "single",
    "thanks",
    "that",
    "think",
    "thinking",
    "this",
    "thumbs",
    "too",
    "tucker",
    "understand",
    "waste",
    "what",
    "xmas",
    "yeah",
    "yoda",
    "you",
    "zayn",
    "zero",
]
__version__ = "2.3.0"



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['foaap']
setup_kwargs = {
    'name': 'foaap',
    'version': '2.3.1',
    'description': 'Fuck Off As A Package',
    'long_description': '# FOAAP\n\n*[FOAAS API v2.3.1](https://foaas.com/) compliant.*\n\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![codecov](https://codecov.io/gh/ilhomidin/foaap/branch/main/graph/badge.svg?token=O0OYHO9VRT)](https://codecov.io/gh/ilhomidin/foaap)\n\nFOAAP (Fuck Of As A Package) solves a simple [foaas-python](https://github.com/dmpayton/foaas-python) problem — telling people to fuck off, faster.\n\n```python\nimport foaap\n\n\n# Maybe. Maybe not. Maybe fuck yourself. - Syu\nfoaap.maybe("Syu")\n```\n\n\n# Installation\n```bash\npip install foaap\n```\n\n# Supported Operations\n\n- `absolutely(company: str, from_name: str)`\n- `anyway(company: str, from_name: str)`\n- `ashole(from_name: str)`\n- `awesome(from_name: str)`\n- `bag(from_name: str)`\n- `balmer(name: str, company: str, from_name: str)`\n- `back(name: str, from_name: str)`\n- `bday(name: str, from_name: str)`\n- `because(from_name: str)`\n- `blackadder(name: str, from_name: str)`\n- `bm(name: str, from_name: str)`\n- `bucket(from_name: str)`\n- `bus(name: str, from_name: str)`\n- `bye(from_name: str)`\n- `caniuse(tool: str, from_name: str)`\n- `chainsaw(name: str, from_name: str)`\n- `cocksplat(name: str, from_name: str)`\n- `cool(from_name: str)`\n- `cup(from_name: str)`\n- `dalton(name: str, from_name: str)`\n- `dense(from_name: str)`\n- `deraadt(name: str, from_name: str)`\n- `diabetes(from_name: str)`\n- `donut(name: str, from_name: str)`\n- `dosomething(do: str, something: str, from_name: str)`\n- `dumbledore(from_name: str)`\n- `equity(name: str, from_name: str)`\n- `even(from_name: str)`\n- `everyone(from_name: str)`\n- `everything(from_name: str)`\n- `family(from_name: str)`\n- `fascinating(from_name: str)`\n- `fewer(name: str, from_name: str)`\n- `field(name: str, from_name: str, reference: str)`\n- `flying(from_name: str)`\n- `ftfy(from_name: str)`\n- `fts(name: str, from_name: str)`\n- `fyyff(from_name: str)`\n- `gfy(name: str, from_name: str)`\n- `give(from_name: str)`\n- `greed(noun: str, from_name: str)`\n- `holygrail(from_name: str)`\n- `horse(from_name: str)`\n- `idea(from_name: str)`\n- `immensity(from_name: str)`\n- `ing(name: str, from_name: str)`\n- `jinglebells(from_name: str)`\n- `keep(name: str, from_name: str)`\n- `keepcalm(reaction: str, from_name: str)`\n- `king(name: str, from_name: str)`\n- `legend(name: str, from_name: str)`\n- `life(from_name: str)`\n- `linus(name: str, from_name: str)`\n- `logs(from_name: str)`\n- `look(name: str, from_name: str)`\n- `looking(from_name: str)`\n- `lowpoly(from_name: str)`\n- `madison(name: str, from_name: str)`\n- `maybe(from_name: str)`\n- `me(from_name: str)`\n- `mornin(from_name: str)`\n- `no(from_name: str)`\n- `nugget(name: str, from_name: str)`\n- `off(name: str, from_name: str)`\n- `off_with(behavior: str, from_name: str)`\n- `outside(name: str, from_name: str)`\n- `particular(thing: str, from_name: str)`\n- `pink(from_name: str)`\n- `problem(name: str, from_name: str)`\n- `programmer(from_name: str)`\n- `pulp(language: str, from_name: str)`\n- `question(from_name: str)`\n- `ratsarse(from_name: str)`\n- `retard(from_name: str)`\n- `ridiculous(from_name: str)`\n- `rockstar(name: str, from_name: str)`\n- `rtfm(from_name: str)`\n- `sake(from_name: str)`\n- `shakespeare(name: str, from_name: str)`\n- `shit(from_name: str)`\n- `shutup(name: str, from_name: str)`\n- `single(from_name: str)`\n- `thanks(from_name: str)`\n- `that(from_name: str)`\n- `think(name: str, from_name: str)`\n- `thinking(name: str, from_name: str)`\n- `this(from_name: str)`\n- `thumbs(name: str, from_name: str)`\n- `too(from_name: str)`\n- `tucker(from_name: str)`\n- `understand(name: str, from_name: str)`\n- `waste(name: str, from_name: str)`\n- `what(from_name: str)`\n- `xmas(name: str, from_name: str)`\n- `yeah(from_name: str)`\n- `yoda(name: str, from_name: str)`\n- `you(name: str, from_name: str)`\n- `zayn(from_name: str)`\n- `zero(from_name: str)`\n\n',
    'author': 'Ilhomidin Bahoraliev',
    'author_email': 'itilhomidin@yandex.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ilhomidin/foaap',
    'py_modules': modules,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
